@@ -1,4 +1,4 @@
-#### $Id: misc-goodies.R,v 1.41 2012/07/06 07:03:56 maechler Exp $
+#### $Id: misc-goodies.R,v 1.42 2012/11/01 19:54:15 maechler Exp $
 #### misc-goodies.R
 #### ~~~~~~~~~~~~~~  SfS - R - goodies that are NOT in
 ####		"/u/sfs/R/SfS/R/u.goodies.R"
@@ -340,7 +340,7 @@ polyn.eval <- function(coef, x)
 
 ## negative x .. may make sense in some cases,.... but not yet :
 ##digitsBase <- function(x, base = 2, ndigits = 1 + floor(log(max(abs(x)),base)))
-digitsBase <- function(x, base = 2, ndigits = 1 + floor(log(max(x),base)))
+digitsBase <- function(x, base = 2, ndigits = 1 + floor(1e-9+ log(max(x),base)))
 {
     ## Purpose: Give the vector A of the base-_base_ representation of _n_:
     ## -------  n = sum_{k=0}^M  A_{M-k} base ^ k ,   where  M = length(a) - 1
